@@ -133,78 +133,6 @@ doEvent <- function(sim, debug = FALSE, notOlderThan,
       }
       if (attr(sim, "needDebug")) {
         debugMessage(debug, sim, cur, fnEnv, curModuleName)
-        # if (!is(debug, "list") && !is.character(debug)) debug <- list(debug)
-        # for (i in seq_along(debug)) {
-        #   if (isTRUE(debug[[i]]) | identical(debug[[i]], "current") | identical(debug[[i]], "step")) {
-        #     if (length(cur) > 0) {
-        #       if (debug[[i]] == "step") {
-        #         if (interactive())
-        #           readline("Press any key to continue...")
-        #       }
-        #
-        #       evnts1 <- data.frame(current(sim))
-        #       evnts1new <- data.frame(current(sim))
-        #       widths <- unname(unlist(lapply(format(evnts1), nchar)))
-        #       .pkgEnv[[".spadesDebugWidth"]] <- pmax(widths, .pkgEnv[[".spadesDebugWidth"]])
-        #       evnts1[1L, ] <- sprintf(paste0("%-",.pkgEnv[[".spadesDebugWidth"]],"s"), evnts1)
-        #       if (.pkgEnv[[".spadesDebugFirst"]]) {
-        #         evnts2 <- evnts1
-        #         evnts2 <- evnts1
-        #         evnts2[1L:2L, ] <- rbind(sprintf(paste0("%-",.pkgEnv[[".spadesDebugWidth"]],"s"), names(evnts2)),
-        #                                     sprintf(paste0("%-",.pkgEnv[[".spadesDebugWidth"]],"s"), evnts2))
-        #
-        #         outMess <- paste(unname(evnts2[1, ]), collapse = ' ')
-        #         outMess <- c(outMess, paste(unname(evnts2[2, ]), collapse = ' '))
-        #         # write.table(evnts2, quote = FALSE, row.names = FALSE, col.names = FALSE)
-        #         .pkgEnv[[".spadesDebugFirst"]] <- FALSE
-        #       } else {
-        #         colnames(evnts1) <- NULL
-        #         # write.table(evnts1, quote = FALSE, row.names = FALSE)
-        #         outMess <- paste(unname(evnts1), collapse = ' ')
-        #       }
-        #     }
-        #   } else if (identical(debug[[i]], 1)) {
-        #     outMess <- paste0(" total elpsd: ", format(Sys.time() - sim@.xData$._startClockTime, digits = 2),
-        #                                  " | ", paste(format(unname(current(sim)), digits = 4), collapse = " "))
-        #   } else if (identical(debug[[i]], 2)) {
-        #     compareTime <- if (is.null(attr(sim, "completedCounter")) ||
-        #                        attr(sim, "completedCounter") == 1) {
-        #       sim@.xData$._startClockTime
-        #     } else {
-        #       .POSIXct(sim@completed[[as.character(attr(sim, "completedCounter") - 1)]]$._clockTime)
-        #     }
-        #     outMess <- paste0(" elpsd: ", format(Sys.time() - compareTime, digits = 2),
-        #                                  " | ", paste(format(unname(current(sim)), digits = 4), collapse = " "))
-        #   } else {
-        #     if (is(debug[[i]], "call")) {
-        #       outMess <- try(eval(debug[[i]]))
-        #     } else if (identical(debug[[i]], "simList")) {
-        #       outMess <- try(capture.output(sim))
-        #     } else if (isTRUE(grepl(debug[[i]], pattern = "\\("))) {
-        #       outMess <- try(eval(parse(text = debug[[i]])))
-        #     } else if (isTRUE(any(debug[[i]] %in% unlist(cur[c("moduleName", "eventType")])))) {
-        #       if (is.environment(fnEnv)) {
-        #         if (all(debug[[i]] %in% unlist(cur[c("moduleName", "eventType")]))) {
-        #           debugonce(get(paste0("doEvent.", curModuleName), envir = fnEnv))
-        #           on.exit(get(paste0("doEvent.", curModuleName), envir = fnEnv))
-        #         }
-        #       }
-        #     } else if (!any(debug[[i]] %in% c("browser"))) { # any other
-        #       if (!is.function(debug[[i]])) {
-        #         outMess <- try(do.call(debug[[i]], list(sim)))
-        #       } else  {
-        #         outMess <- try(debug[[i]](sim))
-        #       }
-        #     }
-        #   }
-        #   if (is.data.frame(outMess)) {
-        #     reproducible::messageDF(outMess, colour = "green", colnames = FALSE)
-        #   } else {
-        #     w <- getOption("width")
-        #     suppress <- lapply(outMess, function(x)
-        #       message(crayon::green(substring(x, first = 1, last = w - 30))))
-        #   }
-        # }
       }
 
       # if the moduleName exists in the simList -- i.e,. go ahead with doEvent
@@ -940,6 +868,22 @@ setMethod(
                         .plots,
                         ...) {
 
+    if (is.character(getOption("spades.covr", FALSE)) &&  getOption("spades.covr2", TRUE) ) {
+      modNam <- getOption("spades.covr")
+      tf <- tempfile();
+      on.exit(unlink(tf))
+      cat(file = tf, paste('spades(sim, events = ',capture.output(dput(events)),', .plotInitialTime = ', .plotInitialTime, ')', collapse = "\n"))
+      # unlockBinding(modNam, sim$.mods)
+      sim$.mods[[modNam]]$sim <- sim
+      opts <- options("spades.covr2" = FALSE) # turn off this chunk 2nd time through
+      on.exit(options(opts), add = TRUE)
+      aa <- covr::environment_coverage(sim$.mods[[modNam]], test_files = tf)
+      rm(list = "sim", envir = sim$.mods[[modNam]])
+      options("spades.covr2" = TRUE)
+      if (is.null(.pkgEnv$._covr)) .pkgEnv$._covr <- list()
+      .pkgEnv$._covr <- append(.pkgEnv$._covr, list(aa))
+      return(.pkgEnv$.sim)
+    }
     oldWd <- getwd()
     on.exit({
       setwd(oldWd)
@@ -1004,7 +948,7 @@ setMethod(
           unspecifiedEvents <- setdiff(unspecifiedEvents, "save")
         if (NROW(sim@inputs) == 0L)
           unspecifiedEvents <- setdiff(unspecifiedEvents, "load")
-        useChkpnt <- !any(is.na(P(sim, ".checkpoint")))
+        useChkpnt <- !any(is.na(params(sim)$checkpoint))
         if (!useChkpnt)
           unspecifiedEvents <- setdiff(unspecifiedEvents, "checkpoint")
         if (length(unspecifiedEvents)) {
@@ -1148,10 +1092,11 @@ setMethod(
         existingCompleted <- sort(as.integer(ls(sim@completed, sorted = FALSE)))
         prevStart <- get(as.character(existingCompleted[1]), envir = sim@completed)
         prevEnd <- get(as.character(existingCompleted[length(existingCompleted)]), envir = sim@completed)
-        if (start(sim, unit = attr(prevStart[["eventTime"]], "unit")) <= prevStart[["eventTime"]] &&
-            (time(sim, unit = attr(prevStart[["eventTime"]], "unit")) ==
-             start(sim, unit = attr(prevStart[["eventTime"]], "unit"))))
-          sim@completed <- new.env(parent = emptyenv())
+        if (length(.grepSysCalls(sys.calls(), "restartSpades")) == 0)
+          if (start(sim, unit = attr(prevStart[["eventTime"]], "unit")) <= prevStart[["eventTime"]] &&
+              (time(sim, unit = attr(prevStart[["eventTime"]], "unit")) ==
+               start(sim, unit = attr(prevStart[["eventTime"]], "unit"))))
+            sim@completed <- new.env(parent = emptyenv())
       }
 
       if (recoverMode > 0) {
@@ -1531,7 +1476,7 @@ messageInterrupt1 <- function(recoverMode) {
 
 setupDebugger <- function(debug = getOption("spades.debug")) {
   if (!missing(debug)) {
-    if (!.isFALSE(debug)) {
+    if (!isFALSE(debug)) {
       if (is.list(debug)) {
         needInstall("logging",
                     messageStart = "debug cannot be a list unless logging package is installed: ")
@@ -1573,7 +1518,7 @@ setupDebugger <- function(debug = getOption("spades.debug")) {
           }
           logging::setLevel(fileLevel, logging::getHandler(logging::writeToFile))
           cat(file = debug$file$file, "##################################\n",
-              append = !.isFALSE(debug$file$append)) # default append it TRUE
+              append = !isFALSE(debug$file$append)) # default append it TRUE
         }
         # with(getLogger(), names(handlers))
 
